package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.SysApplicationCase;

public interface SysApplicationCaseMapper
{
    public SysApplicationCase selectSysApplicationCaseById(Long id);

    public List<SysApplicationCase> selectSysApplicationCaseList(SysApplicationCase sysApplicationCase);

    public int insertSysApplicationCase(SysApplicationCase sysApplicationCase);

    public int updateSysApplicationCase(SysApplicationCase sysApplicationCase);

    public int deleteSysApplicationCaseById(Long id);

    public int deleteSysApplicationCaseByIds(Long[] ids);
}
